summaryrefslogtreecommitdiff
path: root/src/mesa/state_tracker/st_atom_depth.c
diff options
context:
space:
mode:
authorKeith Whitwell <keith@tungstengraphics.com>2007-06-14 18:23:43 +0100
committerKeith Whitwell <keith@tungstengraphics.com>2007-06-14 18:23:43 +0100
commit943964a1e5bad86bdceb0a06d60fb3b302ebce6a (patch)
treea4ed47408b6d7a856b510ae68230d0ba3479071f /src/mesa/state_tracker/st_atom_depth.c
parent6393cda6766b707ef01e925d378239a66d143ae0 (diff)
Rename directories again?!
Some git wierdness going on.
Diffstat (limited to 'src/mesa/state_tracker/st_atom_depth.c')
-rw-r--r--src/mesa/state_tracker/st_atom_depth.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/mesa/state_tracker/st_atom_depth.c b/src/mesa/state_tracker/st_atom_depth.c
index 5532abc8fd..4c891e6e54 100644
--- a/src/mesa/state_tracker/st_atom_depth.c
+++ b/src/mesa/state_tracker/st_atom_depth.c
@@ -34,25 +34,25 @@
#include "st_context.h"
#include "st_atom.h"
-#include "softpipe/sp_context.h"
-#include "softpipe/sp_defines.h"
+#include "pipe/p_context.h"
+#include "pipe/p_defines.h"
/**
* Convert GLenum depth func tokens to softpipe tokens.
*/
static GLuint
gl_depth_func_to_sp(GLenum func)
{
/* Same values, just biased */
- assert(SP_DEPTH_FUNC_NEVER == GL_NEVER - GL_NEVER);
- assert(SP_DEPTH_FUNC_LESS == GL_LESS - GL_NEVER);
- assert(SP_DEPTH_FUNC_EQUAL == GL_EQUAL - GL_NEVER);
- assert(SP_DEPTH_FUNC_LEQUAL == GL_LEQUAL - GL_NEVER);
- assert(SP_DEPTH_FUNC_GREATER == GL_GREATER - GL_NEVER);
- assert(SP_DEPTH_FUNC_NOTEQUAL == GL_NOTEQUAL - GL_NEVER);
- assert(SP_DEPTH_FUNC_GEQUAL == GL_GEQUAL - GL_NEVER);
- assert(SP_DEPTH_FUNC_ALWAYS == GL_ALWAYS - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_NEVER == GL_NEVER - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_LESS == GL_LESS - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_EQUAL == GL_EQUAL - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_LEQUAL == GL_LEQUAL - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_GREATER == GL_GREATER - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_NOTEQUAL == GL_NOTEQUAL - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_GEQUAL == GL_GEQUAL - GL_NEVER);
+ assert(PIPE_DEPTH_FUNC_ALWAYS == GL_ALWAYS - GL_NEVER);
assert(func >= GL_NEVER);
assert(func <= GL_ALWAYS);
return func - GL_NEVER;
@@ -62,7 +62,7 @@ gl_depth_func_to_sp(GLenum func)
static void
update_depth( struct st_context *st )
{
- struct softpipe_depth_state depth;
+ struct pipe_depth_state depth;
memset(&depth, 0, sizeof(depth));
@@ -74,7 +74,7 @@ update_depth( struct st_context *st )
if (memcmp(&depth, &st->state.depth, sizeof(depth)) != 0) {
/* state has changed */
st->state.depth = depth; /* struct copy */
- st->softpipe->set_depth_state(st->softpipe, &depth); /* set new state */
+ st->pipe->set_depth_state(st->pipe, &depth); /* set new state */
}
}
@@ -34,25 +34,25 @@
/**
- * Convert GLenum depth func tokens to softpipe tokens.
+ * Convert GLenum depth func tokens to pipe tokens.
*/
static GLuint